[Compare the full difference.](https://github.com/callowayproject/bump-my-version/compare/1.1.3...1.1.4)

### Fixes

- Fixed test assertion from stdout to output. [e59c7f7](https://github.com/callowayproject/bump-my-version/commit/e59c7f7df90068c0ace90835cf76865283451636)
    
- Fixes typing issues for python 3.8. [78d5009](https://github.com/callowayproject/bump-my-version/commit/78d5009a04f658e245d21e8c48740fba9f48637c)
    
